@@ -1,4 +1,4 @@
-# $Id: search.rb,v 1.127 2004/06/25 07:12:08 ianmacd Exp $
+# $Id: search.rb,v 1.129 2004/09/22 09:58:29 ianmacd Exp $
 #
 
 require 'amazon'
@@ -331,7 +331,7 @@ module Amazon
       # Ruby/Amazon will detect this and channel all outbound connections via
       # your proxy server.
       #
-      def initialize(dev_token=nil, associate=nil, locale=nil, cache=true,
+      def initialize(dev_token=nil, associate=nil, locale=nil, cache=nil,
 		     user_agent = USER_AGENT)
 
 	def_locale = locale
@@ -352,7 +352,7 @@ module Amazon
 	      # Skip comments and blank lines
 	      next if line =~ /^(#|$)/
 
-	      Amazon::dprintf("Read: %s", line)
+	      Amazon::dprintf("Read: %s\n", line)
 
 	      # Store these, because we'll probably find a use for these later
 	      begin
@@ -387,7 +387,7 @@ module Amazon
 	@id	    = associate || DEFAULT_ID[locale]
 	@locale	    = locale
 	@user_agent = user_agent
-	@cache	    = if cache
+	@cache	    = unless cache == false
 			Amazon::Search::Cache.new(@config['cache_dir'] ||
 						  '/tmp/amazon')
 		      else
@@ -750,7 +750,7 @@ module Amazon
 		       &block)
 
 	url = AWS_PREFIX + "?t=%s&PowerSearch=%s&mode=%s&f=xml" +
-	      "&type=%s&dev-t=%s&page=%"
+	      "&type=%s&dev-t=%s&page=%s"
 	url << "&variations=yes" if editions == ALL_EDITIONS
 	url << get_offer_string(offerings)
 	sort_string = get_sort_string(sort_type, mode)
